pygeodesy.deprecated.nvector

Package pygeodesy :: Package deprecated :: Module nvector |
[frames] | no frames]

# Module nvector

DEPRECATED on 2021.05.20, use (INTERNAL) module pygeodesy.nvectorBase instead.

Version: 23.11.26

Classes
| LatLonNvectorBase (INTERNAL) Base class for n-vector-based ellipsoidal and spherical `LatLon`s.
| Nvector DEPRECATED on 2021.05.20, see (INTERNAL) class pygeodesy.nvectorBase.NvectorBase.

Functions
sumOf(nvectors, Vector=None, h=None, **Vector_kwds) Return the vectorial sum of two or more n-vectors. |

Variables
| NorthPole = `_N_Vector(0, 0, 1)`
| SouthPole = `_N_Vector(0, 0, -1)`
| __all__ = `_ALL_DEPRECATED.deprecated_nvector`

Function Details

### sumOf (nvectors, Vector=None, h=None, **Vector_kwds) |
Return the vectorial sum of two or more n-vectors. Arguments: `nvectors` - Vectors to be added (`Nvector`[]). `Vector` - Optional class for the vectorial sum (`Nvector`) or `None`. `h` - Optional height, overriding the mean height (`meter`). `Vector_kwds` - Optional, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: Vectorial sum (`Vector`) or a Vector4Tuple`(x, y, z, h)` if `Vector is None`. Raises: `VectorError` - No `nvectors`.